<?php
/*
=================================================================================================================
mixano_get_purchase_code() - get the envato purchase code from db or from envato if hosted there
=================================================================================================================
*/
function mixano_get_purchase_code() {
	
	$purchase_code = get_option( 'mixano_purchase_code' );
	
	if( isset( $purchase_code ) ) {
		return $purchase_code;
	}
	return false;
	
}
/*
=================================================================================================================
mixano_license_active()
=================================================================================================================
*/
function mixano_license_active() {
	
	$isActive = get_option( 'mixano_license_active' );
	
	if( $isActive == 'active' ){
		return true;
	}
	
	return false;
	
}
/*
=================================================================================================================
mixano_plugin_updater() - plugin updater
=================================================================================================================
*/
add_action( 'admin_init', 'mixano_plugin_updater' );
function mixano_plugin_updater() {

if ( !class_exists ( 'TGM_Updater' ) ){
	require_once( MIXANO_PLUGIN_DIR .'/inc/tgm/class-tgm-updater.php' );
}

	//Codestar Framework
	if( class_exists( 'CSF' ) ) {
		$plugin_data = get_plugin_data( trailingslashit( WP_PLUGIN_DIR ).'codestar-framework/codestar-framework.php');
		$args = array(
			'plugin_name' => esc_html__('Codestar Framework', 'mixano'),
			'plugin_slug' => 'codestar-framework',
			'plugin_path' => 'codestar-framework/codestar-framework.php',
			'plugin_url'  => trailingslashit( WP_PLUGIN_URL ) . 'codestar-framework',
			'remote_url'  => esc_url( 'https://wowlayers.live/tf/themes/mixano/codestar-framework.json' ),
			'version'     => $plugin_data['Version'],
			'key'         => ''
		);
		$tgm_updater = new TGM_Updater( $args );
	}
	
	//Mixano Core
	if( function_exists( 'mixano_plugins_core' ) ) {
		$plugin_data = get_plugin_data( trailingslashit( WP_PLUGIN_DIR ).'mixano-core/mixano.php');
		$args = array(
			'plugin_name' => esc_html__('Mixano Core', 'mixano'),
			'plugin_slug' => 'mixano-core',
			'plugin_path' => 'mixano-core/mixano.php',
			'plugin_url'  => trailingslashit( WP_PLUGIN_URL ) . 'mixano-core',
			'remote_url'  => esc_url( 'https://wowlayers.live/tf/themes/mixano/mixano-core.json' ),
			'version'     => $plugin_data['Version'],
			'key'         => ''
		);
		$tgm_updater = new TGM_Updater( $args );
	}	
}

/*
=================================================================================================================
mixano_upgrader_pre_download() - Get the secure download URL of a package ( theme / plugin )
=================================================================================================================
*/
function mixano_upgrader_pre_download( $reply, $package, $upgrader ) {
	
	if( strpos( $package, 'wowlayers.live' ) !== false ) {
		
		//check if there is any purchase code registered
		if( !mixano_get_purchase_code() ) {
			if ( !$upgrader->bulk ){
				return new WP_Error('mixano-code-empty', sprintf( wp_kses_post( __( '<div class="notice notice-error is-dismissible"><p>Purchase code verification failed. <a href="%s">Activate Mixano</a> in order to be able to download / update.</p></div>', 'mixano' ) ),esc_url( admin_url( 'admin.php?page=mixano-options#tab=activate-theme' ) ) ) );
			}
			else{
				return new WP_Error('mixano-code-empty', sprintf( wp_kses_post( __( 'Purchase code verification failed. <a href="%s">Activate Mixano</a> in order to be able to download / update', 'mixano' ) ),esc_url( admin_url( 'admin.php?page=mixano-options#tab=activate-theme' ) ) ) );
			}
		}

		//checks
		$query = add_query_arg( array(
			'code' => mixano_get_purchase_code(),
			'site_url' => get_site_url(),
			'package' => $package,
		), 'https://wowlayers.live/tf/key.php' );			

		//get response
		$response = wp_remote_get( $query, array( 'timeout' => 20 ) );
		
		//if response error
		if ( is_wp_error( $response ) ) {
			return new WP_Error('mixano_communication_error', sprintf( __( 'Could not communicate with Mixano server. Please try again or contact us if the problem persists.','mixano' ) ) );
		}
		
		//license checks
		if( $response['body'] ){
			if ( !$upgrader->bulk ){
				return new WP_Error( 'license_checks' , sprintf( wp_kses_post( '<div class="notice notice-error is-dismissible"><p>'. esc_attr( $response['body'] ).'</p></div>' ) ) );
			}
			else{
				return new WP_Error( 'license_checks' , esc_attr( $response['body'] ) );			
			}
		}

		//sucess - package download url
		$download_url = download_url( 'http://wowlayers.live/tf/download.php?code='.esc_attr( mixano_get_purchase_code() ).'&package='.esc_attr( $package ).'&site_url='.esc_url( get_site_url() ) );
		
		//if package error
		if ( is_wp_error( $download_url ) ) {
			return new WP_Error('mixano_communication_error', sprintf( __( 'Could not communicate with Mixano server. Please try again or contact us if the problem persists.','mixano' ) ) );
		}

		return $download_url;
		
	}

	return $reply;

}
add_filter( 'upgrader_pre_download', 'mixano_upgrader_pre_download', 10, 3 );


/*
=================================================================================================================
mixano_pre_set_site_transient_update_themes() - check for theme updates
=================================================================================================================
*/
function mixano_pre_set_site_transient_update_themes( $transient ) {

	$response = wp_remote_get( 'https://wowlayers.live/tf/themes/mixano/mixano.json', array( 'timeout' => 5 ) );
	
	if ( is_wp_error( $response ) ) {
		return $transient;
	}

	$body = wp_remote_retrieve_body( $response );
	
	$data = json_decode( $body, 1 );
	if ( ! isset( $data['new_version'] ) ) {
		return $transient;
	}

	$new_version = $data['new_version'];

	// Save update info there is a new version
	$theme = wp_get_theme('mixano');
	if ( version_compare( $theme->get( 'Version' ), $new_version, '<' ) ) {
		$transient->response[ 'mixano' ] = array(
			'slug' => 'mixano',
			'theme' => 'mixano',
			'new_version' => $new_version,
			'url' => $data['url'],
			'package' => $data['package'],
			'changelog' => $data['changelog'],
		);
	}

	return $transient;
}
add_filter( 'pre_set_site_transient_update_themes', 'mixano_pre_set_site_transient_update_themes', 10, 3 );


/*
=================================================================================================================
mixano_mixano_update_notice() - Display a notice that new version is available
=================================================================================================================
*/
function mixano_mixano_update_notice() {
	
	if ( !current_user_can('update_themes' ) ){
		return false;
	}
	
	if ( !isset( $themes_update ) ){
		$themes_update = get_site_transient( 'update_themes' );
	}
	
	if ( isset( $themes_update->response['mixano'] ) ) {
		
		$update = $themes_update->response['mixano'];
		$theme = wp_prepare_themes_for_js( array( wp_get_theme('mixano') ) );
		$update_url = wp_nonce_url( admin_url( 'update.php?action=upgrade-theme&amp;theme=' . urlencode( 'mixano' ) ), 'upgrade-theme_mixano' );
		
		if ( isset( $theme[0] ) && $theme[0]['hasUpdate'] ) {
			
			echo '<div class="mixano-update-notice notice notice-warning is-dismissible">';
			echo '<p>'.sprintf( wp_kses( __( 'There is a new version of Mixano theme available. Your current version is <strong>%s</strong>. Update to <strong>%s</strong>.', 'mixano'), array('strong' => array())), $theme[0]['version'], $update['new_version']).'</p>';
			
			echo '<p><strong><a href="#" class="mixano-view-details-link">View update details</a></strong>'.sprintf( wp_kses( __( ' or <strong><a href="%s" class="mixano-update-link">Update now</a></strong>.', 'mixano'), array('strong' => array(), 'a' => array('href' => array(), 'class' => array()))),  $update_url).'</p>';
			echo '</div>';
			
		}
	}
}
add_action( 'admin_notices', 'mixano_mixano_update_notice' );



/*
=================================================================================================================
mixano_mixano_plugins_update_notice() - Display a notice that new version of plugin(s) is / are available
=================================================================================================================
*/
function mixano_mixano_plugins_update_notice() {
	if ( !current_user_can('update_plugins' ) )
		return false;
	$plugins = get_site_transient('update_plugins');
	$mixano_plugins = array(
		'mixano-core/mixano.php',
	);
	if ( isset( $plugins->response ) && is_array( $plugins->response ) ) {
		
		$plugins_ids = array_keys( $plugins->response );
		
		foreach ( $plugins_ids as $plugin_file ) {
			
			if( in_array( $plugin_file, $mixano_plugins ) ) {
				
				$plugin_data = get_plugin_data( trailingslashit(WP_PLUGIN_DIR).$plugin_file );
				$plugin_update = $plugins->response[$plugin_file];
				
				echo '<div class="mixano-update-notice notice notice-warning is-dismissible">';
				echo '<p>'.sprintf( wp_kses( __( 'There is a new version of <strong>%s</strong> plugin available. Your current version is <strong>%s</strong>. Update to <strong>%s</strong>.', 'mixano'), array( 'strong' => array() ) ), $plugin_data['Name'], $plugin_data['Version'], $plugin_update->new_version ).'</p>';
				echo '<p>'.sprintf( wp_kses( __( '<strong><a href="%s">Update now</a></strong>.', 'mixano' ), array( 'strong' => array(), 'a' => array( 'href' => array() ) ) ), esc_url( admin_url('update-core.php') ) ).'</p>';
				echo '</div>';
				
			}
		}
	}
}
add_action( 'admin_notices', 'mixano_mixano_plugins_update_notice' );

/*
=================================================================================================================
mixano_update_confirmation() - Display a confirmation box on theme update
=================================================================================================================
*/
add_action('wp_ajax_mixano_update_confirmation', 'mixano_update_confirmation');
function mixano_update_confirmation() {
?>
<div class="mixano-update">
	<div class="mixano-update-inner">
		<div class="logo"><img src="<?php echo esc_url( MIXANO_PLUGIN_URI.'/images/logo-icon.png' ); ?>" alt="<?php esc_html_e('Mixano logo', 'mixano'); ?>"></div>
		<div class="confirm-update-holder">
			<h1><i class="wow-webapplication-exclamation-square"></i><?php esc_html_e('Very important notice!', 'mixano'); ?></h1>
			<p>
			<?php 
				printf( '%s<strong>%s</strong>%s<strong>%s</strong>', 
					esc_html__( 'Before you update the theme', 'mixano' ), 
					esc_html__( ' we strongly recommend ', 'mixano' ),
					esc_html__( 'that you make a ', 'mixano' ),
					esc_html__( 'full website and database backup.', 'mixano' )
				); ?>
			</p>			
			<p>
			<?php 
				printf( '%s<strong>%s</strong>%s<strong>%s</strong>%s<strong>%s</strong>', 
					esc_html__( 'If you have ', 'mixano' ), 
					esc_html__( 'modified ', 'mixano' ),
					esc_html__( 'any of the ', 'mixano' ), 
					esc_html__( 'theme files, ', 'mixano' ),
					esc_html__( 'please note that they will be ', 'mixano' ),
					esc_html__( 'overridden.', 'mixano' )
				); ?>
			</p>
			<p class="lighter">
			<?php 
				printf( '%s<br>%s<br>%s<a href="%s" target="_blank">%s</a>', 
					esc_html__( 'Best practice if you want to modify theme files, is to use Mixano child theme instead.', 'mixano' ), 
					esc_html__( ' Child theme is included in the main ZIP package that you downloaded from themeforest.', 'mixano' ),
					esc_html__( ' More info about child themes can be found ', 'mixano' ),
					esc_url( 'https://developer.wordpress.org/themes/advanced-topics/child-themes/'),
					esc_html__( 'here', 'mixano' )
				); ?>			
			</p>		
			<div class="confirm-checkbox">
				<label for="mixano-confirm-checkbox"><input type="checkbox" name="confirm" id="mixano-confirm-checkbox" value="1" />
					<?php esc_html_e('I have read the notice above and I confirm I want to proceed with the update.', 'mixano'); ?>
				</label>
			</div>
			<div class="confirm-button">
				<button id="mixano-confirm-button" disabled="disabled"><?php esc_html_e('Proceed with update', 'mixano'); ?></button>
			</div>
		</div>
	</div>
</div>
<?php
	die(-1);
}

/*
=================================================================================================================
Function wow_purchase_code_activation_handler() - Purchase code activation
=================================================================================================================
*/
function mixano_purchase_code_activation_handler(){

	if( $_POST['action'] == 'mixano_purchase_code' ){
		
		if( $_POST['purchase_code'] ){
			
			$purchase_code = stripslashes( wp_filter_kses( $_POST['purchase_code'] ));
			$purchase_code = trim( $purchase_code );
			
			$query = add_query_arg( array(
				'code' => esc_attr( $purchase_code ),
				'site_url' => get_site_url(),
			), 'https://wowlayers.live/tf/register.php' );

			$response = wp_remote_get( $query, array( 'timeout' => 20 ) );				

			if ( is_wp_error( $response ) ) {
				die( esc_html__("Could not connect to server","mixano") );
			} 
			elseif( $response["body"] == "success" ){
				update_option("mixano_purchase_code", esc_attr( $purchase_code ) );
				update_option("mixano_license_active", "active" );
				die("success");
			}
			else {
				die( $response["body"] );
			}			
			
		}
	}		
} 
add_action('wp_ajax_mixano_purchase_code', 'mixano_purchase_code_activation_handler'); // wp_ajax_{action}


/*
=================================================================================================================
Function mixano_purchase_code_deactivation_handler() - Purchase code deactivation
=================================================================================================================
*/
function mixano_purchase_code_deactivation_handler(){
	
	
	if( $_POST['action'] == 'mixano_purchase_code' && $_POST['do_action'] == 'deregister' ){
		
			
		if( get_option("mixano_purchase_code") && get_option("mixano_license_active") == "active" ){
				
			$query = add_query_arg( array(
				'code' => mixano_get_purchase_code(),
				'site_url' => get_site_url(),
			), 'https://wowlayers.live/tf/deregister.php' );

			$response = wp_remote_get( $query, array( 'timeout' => 20 ) );			
			
			if ( is_wp_error( $response ) ) {
				die( esc_html__("Could not connect to server","mixano") );
			} 
			elseif( $response["body"] == "success" ){
				update_option("mixano_purchase_code", "" );
				update_option("mixano_license_active", "inactive" );
				die("success");
			}
			elseif( $response["body"] == "license-not-found" ) {

					die( esc_html__("License not found","mixano") );
			}	
			else{
				die( $response["body"] );
			}
		}
	}		
} 
add_action('wp_ajax_mixano_purchase_code', 'mixano_purchase_code_deactivation_handler'); // wp_ajax_{action}


/*
=================================================================================================================
infinito_change_log() - Get theme changelog page
=================================================================================================================
*/
add_action('wp_ajax_mixano_change_log', 'mixano_change_log');
function mixano_change_log() {
	
	$response = wp_remote_get( 'https://wowlayers.live/tf/themes/mixano/changelog.html' );
	
	if ( is_array( $response ) ) {
		?>
		<div class="mixano-update changelogs">
		<?php
			$body = $response['body']; // use the content	  
			echo wp_kses_post( $body );
		?>
		<div>
		<?php
		die(-1);
	}	
	

}