<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/*
=================================================================================================================
mixano_get_demo_file() - get the demo package zip file
=================================================================================================================
*/
function mixano_get_demo_file( $package ){

	if( !$package ) return false;
	
	$query = add_query_arg( array(
		'code' => mixano_get_purchase_code(),
		'site_url' => get_site_url(),
		'package' => $package,
	), 'https://wowlayers.live/tf/download.php' );

	$content = wp_remote_get( $query , array( 'timeout' => 60 )  ) ;

	if ( is_wp_error( $content ) ) {
		return esc_html__( 'Could not communicate with Mixano server. Please try again or contact us if the problem persists.','mixano' ) ;
	}
	
	$content_type =  wp_remote_retrieve_header( $content, 'content-type' );
	
	$error = $content_type == 'application/zip' ? false : true;
	
	if( $error ){
		return esc_attr( $content["body"] );
	}
	else{
		if( $content["body"] ){
			
			if( !function_exists( 'get_filesystem_method' ) ){
				require_once( ABSPATH . 'wp-admin/includes/file.php' );
			}
			
			$access_type = get_filesystem_method();
			
			if($access_type === 'direct')
			{
				
				/* you can safely run request_filesystem_credentials() without any issues and don't need to worry about passing in a URL */
				$creds = request_filesystem_credentials(site_url() . '/wp-admin/', '', false, false, array());
				
				/* initialize the API */
				if ( ! WP_Filesystem($creds) ) {
					/* any problems and we exit */
					return false;
				}

				//save file to temp folder
				$package_folder = str_ireplace(".zip","",$package);
				$upload_dir = wp_get_upload_dir();
				$zip_path = $upload_dir["path"] . "/mixano_tmp_folder/";
				$file = $zip_path . "mixano-".esc_attr( $package_folder )."/mixano-".esc_attr( $package );	

				if ( !file_exists( $zip_path ) ) {
					mkdir( $zip_path , 0755);
				}				
				if ( !file_exists( $zip_path . "mixano-".esc_attr( $package_folder ) ) ) {					
					mkdir( $zip_path . "mixano-".esc_attr( $package_folder ) , 0755);
				}
				
				$file_saved = file_put_contents( $file , $content["body"] );
				
				if( $file_saved === false ){
					return esc_html__( "Temp file was not saved",'mixano' ); 
				}
			}			
			else{
				/* don't have direct write access. Prompt user with our notice */
				return esc_html__( "You don't have permission to write.",'mixano' ); 	
			}						
			
			//get path
			$path = pathinfo( realpath( $file ), PATHINFO_DIRNAME );

			$unzipfile = unzip_file( $file , $path );
			if ( !$unzipfile ) {
				return esc_html__( "There was an error unzipping the temp file.",'mixano' );       
			}					
			
			return "success";					
		}
	}
}

/*
=================================================================================================================
mixano_importer_ajax_handler() - importer ajax handler
=================================================================================================================
*/
function mixano_importer_ajax_handler() {
	$error_msg = array();
	$success = true;

	$nonce = $_POST['nonce'];
	if ( ! wp_verify_nonce( $nonce, 'mixano_plugin_data' ) ){
		wp_die ( 'cheatin?');
	}
	
	if( get_option( "mixano_license_active" ) != "active" ){
		echo json_encode(array("success"=>"Activate theme","site_url"=>esc_url( get_site_url() ),"theme_options_url" =>  esc_url( get_admin_url() )."admin.php?page=mixano-options#tab=demo-importer","title"=>$title));
		wp_die();
	}

    if ( current_user_can( 'manage_options' )) {
		
		if( isset( $_POST['action'] )  &&  isset( $_POST['packageVal'] )   ){
			
			$action 				= stripslashes( sanitize_text_field( $_POST['action'] ));
			$package 				= stripslashes( sanitize_text_field( $_POST['packageVal'] ));		

			$delete_posts 			= !empty( sanitize_text_field( $_POST['delete_posts'] ) ) ? sanitize_text_field( $_POST['delete_posts'] ) : false;
			$delete_pages 			= !empty( sanitize_text_field( $_POST['delete_pages'] ) ) ? sanitize_text_field( $_POST['delete_pages'] ) : false;
			$delete_widgets 		= !empty( sanitize_text_field( $_POST['delete_widgets'] ) ) ? sanitize_text_field( $_POST['delete_widgets'] ) : false;
			$delete_menus 			= !empty( sanitize_text_field( $_POST['delete_menus'] ) ) ? sanitize_text_field( $_POST['delete_menus'] ) : false;
			$delete_media 			= !empty( sanitize_text_field( $_POST['delete_media'] ) ) ? sanitize_text_field( $_POST['delete_media'] ) : false;			

			if( $action == 'mixano_importer' && $package ){

				//delete some data if selected
				if ( $delete_posts == 'trash' ){
					mixano_get_all_posts_for_deletion( "post" );
				}
				elseif( $delete_posts == 'delete' ){
					mixano_get_all_posts_for_deletion( "post" , true );
				}
				
				if ( $delete_pages == 'trash' ){
					mixano_get_all_posts_for_deletion( "page" );
				}
				elseif( $delete_pages == 'delete' ){
					mixano_get_all_posts_for_deletion( "page" , true );
				}
				
				if ( $delete_widgets == 'inactive' ){
					mixano_set_inactive_widgets();
				}
				elseif( $delete_widgets == 'delete' ){
					mixano_delete_widgets();
				}
			
				if( $delete_menus == 'delete' ){
					$menus = wp_get_nav_menus();
					if( !empty( $menus ) ){
						foreach($menus as $menu){
							wp_delete_nav_menu( $menu->term_id );
						}
					} 	
				}
				
				if ( $delete_media == 'delete' ){
					mixano_delete_media();
				}
				
				//get file to temp folder
				$response = mixano_get_demo_file( $package.'.zip' );
				if( $response != 'success' ){
					echo json_encode(array("success"=>esc_attr( $response ),"site_url"=>esc_url( get_site_url() ),"theme_options_url" =>  esc_url( get_admin_url() )."admin.php?page=mixano-options#tab=demo-importer"));
					wp_die();
				}
				
				//import theme options

				$response = mixano_importer_theme_options( $package );
				if( $response != 'success' ){
					$error_msg []= $response;
					$success = false;
				}

				//display a message to user if execution time exceeded
				function mixano_handleFatalPhpError() {
				   $last_error = error_get_last();
				   if( $last_error['type'] === E_ERROR ) {
					 if ( stripos( $last_error['message'] , 'Maximum execution' ) !== false ){
						wp_die();
					 }
				   }
				}

				register_shutdown_function('mixano_handleFatalPhpError');							
				
				//import wordpress content
				$response = mixano_importer_wp( $package );
				if( $response != 'success' ){
					$error_msg []= $response;
					$success = false; 						
				}
				else{
					mixano_importer_menus();
				}
				
				//import widgets
				
				$response = mixano_importer_widgets( $package );
				if( $response != 'success' ){
					$error_msg []= $response;
					$success = false;
				}						
				
				//clean the mess - delete zip file and package directory after importing
				
				$upload_dir = wp_get_upload_dir();
				$temp_dir = $upload_dir["path"] . "/mixano_tmp_folder/";
				mixano_delete_temp_Directory( $temp_dir );
				
				
				if( $success == true ){
					echo json_encode(array("success"=>"success","site_url"=>esc_url( get_site_url() ),"theme_options_url" =>  esc_url( get_admin_url() )."admin.php?page=mixano-options#tab=demo-importer"));
				}
				else{
					echo json_encode(array("success"=>$error_msg,"site_url"=>esc_url( get_site_url() ),"theme_options_url" =>  esc_url( get_admin_url() )."admin.php?page=mixano-options#tab=demo-importer"), JSON_FORCE_OBJECT);					
				}
				
				wp_die();			
			}
		}		
	}
	echo json_encode(array("success"=>"fail","site_url"=>esc_url( get_site_url() ),"theme_options_url" => esc_url( get_admin_url() )."admin.php?page=mixano-options#tab=demo-importer"));
	wp_die();
} 
add_action('wp_ajax_mixano_importer', 'mixano_importer_ajax_handler'); // wp_ajax_{action}

/*
=================================================================================================================
mixano_importer_theme_options() - theme options importer
=================================================================================================================
*/
function mixano_importer_theme_options	( $package = null ){

	if( !$package ) return esc_html__( 'For some reason theme options were not imported.','mixano' );
	
	$upload_dir = wp_get_upload_dir(); 
	
	$file = $upload_dir["path"] . "/mixano_tmp_folder/mixano-" . $package . "/to.json";
	
	$content = file_get_contents( $file );
	$options = json_decode($content, true);
	
	$update = update_option('mixano_options',$options);
	
	return "success";
}


/*
=================================================================================================================
mixano_importer_wp() - wordpress content importer
=================================================================================================================
*/	
function mixano_importer_wp( $package = null ){
	
	if( !$package ) return esc_html__( 'For some reason content was not imported.','mixano' );
		
	if ( !defined('WP_LOAD_IMPORTERS') ) define('WP_LOAD_IMPORTERS', true); // we are loading importers

	if ( ! class_exists( 'WP_Importer' ) ) { // if main importer class doesn't exist
		$wp_importer = ABSPATH . 'wp-admin/includes/class-wp-importer.php';
		include $wp_importer;
	}
	
	$wp_import = MIXANO_PLUGIN_DIR . '/inc/importer/wordpress-importer.php';
	include $wp_import;

	if ( class_exists( 'WP_Importer' ) && class_exists( 'WP_Import_Theme_Content' ) ) { // check for main import class and wp import class


		$upload_dir = wp_get_upload_dir(); 
		$file = $upload_dir["path"] . "/mixano_tmp_folder/mixano-" . $package . "/content.xml";
					
		$importer = new WP_Import_Theme_Content();
		$file_clean = trim(preg_replace('/\s+/', ' ', $file)); //importer is buggy if has the XML file contain strings with new lines
		$importer->fetch_attachments = true;
		ob_start();
		$importer->import($file_clean);
		ob_end_clean();						
						
		return "success";
	}
	
	return esc_html__( 'For some reason content was not imported.','mixano' );
}

/*
=================================================================================================================
mixano_parse_temp_files() - parse all the files in a given path
=================================================================================================================
*/
function mixano_parse_temp_files( $path ){
$return = array();
	$files = array_diff( scandir( $path ), array( '..', '.' ) );
	foreach( $files as $file ){
		
		if ( strpos( $file, 'rev_slider') !== false) {
			$return []= $path."/".$file;
		}		
	}
	return $return;
}
	
/*
=================================================================================================================
mixano_importer_menus() - menu importer
=================================================================================================================
*/
function mixano_importer_menus(){
	$locations = array();
	
	mixano_demo_menu();
	
    $menus = wp_get_nav_menus(); // registered menus
	
		if( is_array( $menus ) ){
				
			foreach( $menus as $menu ) {
					
				if( $menu->name == 'Demo' ) {
					$locations['primary'] = $menu->term_id;
				}				
			}
			set_theme_mod( 'nav_menu_locations', $locations ); // set Main menu to locations
			
			return true;
		}
		
	return false;
}


/*
=================================================================================================================
mixano_demo_menu - Create demo menu
=================================================================================================================
*/

function mixano_demo_menu() {

		register_nav_menus( array( 'primary' => 'Demo' ) );
		$menu_id = wp_create_nav_menu('Demo');
		
		if ( $menu_id > 0 ) {
			$home_url = home_url( '/' );
			$menu_items = array(
				array( 'title' => 'Home' , 'url' => esc_url( $home_url ) ),				
				array( 'title' => 'Sample Page' , 'url' => esc_url( $home_url . 'sample-page') ),
				array( 'title' => 'Contact Us' , 'url' => esc_url( $home_url . 'contact-us') ),
			);	
			
			foreach($menu_items as $menu_item){
				$page_args = array(
					'menu-item-title' => $menu_item['title'],
					'menu-item-url' => esc_url($menu_item['url']),
					'menu-item-status' => 'publish',
					'menu-item-type' => 'custom',			
				);				
				wp_update_nav_menu_item( $menu_id , 0, $page_args );
			}			
		}
	
}

/*
=================================================================================================================
mixano_importer_widgets() - widgets importer
=================================================================================================================
*/
function mixano_importer_widgets( $package ){
	
	if( !$package ) return false;
	global $wp_filesystem;

	$upload_dir = wp_get_upload_dir(); 
	$file = $upload_dir["path"] . "/mixano_tmp_folder/mixano-" . $package . "/widget_data.json";
		
	$content = file_get_contents( $file );	
	return mixano_parse_widgets( $content );
	
}

/*
=================================================================================================================
mixano_parse_widgets() - parse widgets
=================================================================================================================
*/
function mixano_parse_widgets( $data ) {
    
	$widgets = array();
    $json_data = json_decode( $data, true );

    $sidebar_data = $json_data[0];
    $widget_data = $json_data[1];
	
	if( !is_array( $sidebar_data ) && empty( $sidebar_data ) && !is_array( $widget_data ) && empty( $widget_data ) ){
		return esc_html__( 'Something went wrong with the widget import. Code:200.','mixano' );		
	}
	
	foreach( $widget_data as $key=> $val){

		foreach(  $val as $jjj => $number){
	
			if( is_int($jjj) ){
				$widgets[$key][$jjj] = 'on';
			}
		}
	}

	foreach ( $sidebar_data as $title => $sidebar ) {
		$count = count( $sidebar );
		for ( $i = 0; $i < $count; $i++ ) {
			$widget = array( );
			$widget['type'] = trim( substr( $sidebar[$i], 0, strrpos( $sidebar[$i], '-' ) ) );
			$widget['type-index'] = trim( substr( $sidebar[$i], strrpos( $sidebar[$i], '-' ) + 1 ) );
			
			
			if ( !isset( $widgets[$widget['type']][$widget['type-index']] ) ) {
				unset( $sidebar_data[$title][$i] );
			}
			
		}
		$sidebar_data[$title] = array_values( $sidebar_data[$title] );
	}

	foreach ( $widgets as $widget_title => $widget_value ) {
		foreach ( $widget_value as $widget_key => $widget_value ) {
			$widgets[$widget_title][$widget_key] = $widget_data[$widget_title][$widget_key];
		}
	}

	$sidebar_data = array( array_filter( $sidebar_data ), $widgets );

    return mixano_parse_widgets_data( $sidebar_data );
}

/*
=================================================================================================================
mixano_parse_widgets_data() - parse widgets data
=================================================================================================================
*/
function mixano_parse_widgets_data( $import_array ) {
    global $wp_registered_sidebars;

	if(  !is_array( $import_array ) && empty( $import_array ) ){
		return esc_html__( 'Something went wrong with the widget import. Code:201.','mixano' );	
	}

    $sidebars_data = $import_array[0];
    $widget_data = $import_array[1];
	
    $current_sidebars = get_option( 'sidebars_widgets' );
    $new_widgets = array( );

	foreach ( $sidebars_data as $import_sidebar => $import_widgets ) {

		foreach ( $import_widgets as $import_widget ) {
								
				$title = trim( substr( $import_widget, 0, strrpos( $import_widget, '-' ) ) );
				$index = trim( substr( $import_widget, strrpos( $import_widget, '-' ) + 1 ) );
				$current_widget_data = get_option( 'widget_' . $title );
				$new_widget_name = mixano_get_new_widget_name( $title, $index );
				$new_index = trim( substr( $new_widget_name, strrpos( $new_widget_name, '-' ) + 1 ) );

				if ( !empty( $new_widgets[ $title ] ) && is_array( $new_widgets[$title] ) ) {
					while ( array_key_exists( $new_index, $new_widgets[$title] ) ) {
						$new_index++;
					}
				}
					
				$current_sidebars[$import_sidebar][] = $title . '-' . $new_index;
					
				if ( array_key_exists( $title, $new_widgets ) ) {
					$new_widgets[$title][$new_index] = $widget_data[$title][$index];
					$multiwidget = $new_widgets[$title]['_multiwidget'];
					unset( $new_widgets[$title]['_multiwidget'] );
					$new_widgets[$title]['_multiwidget'] = $multiwidget;
				}
					
				else {
					$current_widget_data[$new_index] = $widget_data[$title][$index];
					$current_multiwidget = array_key_exists('_multiwidget', $current_widget_data) ? $current_widget_data['_multiwidget'] : false;
					$new_multiwidget = array_key_exists('_multiwidget', $widget_data[$title]) ? $widget_data[$title]['_multiwidget'] : false;
					$multiwidget = ($current_multiwidget != $new_multiwidget) ? $current_multiwidget : 1;
					unset( $current_widget_data['_multiwidget'] );
					$current_widget_data['_multiwidget'] = $multiwidget;
					$new_widgets[$title] = $current_widget_data;
				}
				

		}
	}

	if ( isset( $new_widgets ) && isset( $current_sidebars ) ) {
		update_option( 'sidebars_widgets', $current_sidebars );

		foreach ( $new_widgets as $title => $content ) {
			
			//Navigation menu widget : add the id of the menu
			if( $title == 'nav_menu' ){
				$content = mixano_change_widget_menu_id( "nav_menu", $content );				
			}
			
			$content = apply_filters( 'widget_data_import', $content, $title );
			update_option( 'widget_' . $title, $content );
		}

		return "success";
	}

	return esc_html__( 'Something went wrong with the widget import. Code:202.','mixano' );
}

/*
=================================================================================================================
mixano_change_widget_menu_id() - change the id of the menu for Navigation menu widget
=================================================================================================================
*/
function mixano_change_widget_menu_id( $needle_key,  $array ){
  
  foreach($array AS $key => &$value){   
    if(is_array($value)){
		foreach( $value AS $key2 => &$value2 ){
			if( $key2 == $needle_key ){
				$value2 =  mixano_get_menu_id_for_nav_menu_widget();
			}
		}
    }
  }	
  return $array;
}



/*
=================================================================================================================
mixano_get_menu_for_nav_menu_widget() - Footer links menu id or some valid menu id
=================================================================================================================
*/
function mixano_get_menu_id_for_nav_menu_widget(){
    $menus = wp_get_nav_menus(); // registered menus
		if(is_array($menus)){
				
			foreach($menus as $menu) {
					
				if( $menu->name == 'Footer links' ) {
					return $menu->term_id;
				} 
			}
			//if menu Footer links is not found get another menu
			return $menu->term_id;
		}	
}

/*
=================================================================================================================
mixano_get_new_widget_name() - get widgets name
=================================================================================================================
*/
function mixano_get_new_widget_name( $widget_name, $widget_index ) {
		
		$current_sidebars = get_option( 'sidebars_widgets' );
		$all_widget_array = array( );
		foreach ( $current_sidebars as $sidebar => $widgets ) {
			if ( !empty( $widgets ) && is_array( $widgets ) && $sidebar != 'wp_inactive_widgets' ) {
				foreach ( $widgets as $widget ) {
					$all_widget_array[] = $widget;
				}
			}
		}
		while ( in_array( $widget_name . '-' . $widget_index, $all_widget_array ) ) {
			$widget_index++;
		}
		$new_widget_name = $widget_name . '-' . $widget_index;
		return $new_widget_name;
}

/*
=================================================================================================================
mixano_delete_temp_Directory() - delete temp directory/directories/files created when importing a demo
=================================================================================================================
*/
function mixano_delete_temp_Directory( $dir ) {
	
    if ( !file_exists( $dir ) ) {
        return true;
    }

    if ( !is_dir( $dir ) ) {
        return unlink( $dir );
    }

    foreach ( scandir( $dir ) as $item ) {
        if ( $item == '.' || $item == '..' ) {
            continue;
        }

        if ( !mixano_delete_temp_Directory( $dir . DIRECTORY_SEPARATOR . $item ) ) {
            return false;
        }

    }

    return rmdir( $dir );
}