<?php

if( ! class_exists( 'CSF_Field_import' ) && class_exists( 'CSF_Fields' ) ) {
  class CSF_Field_import extends CSF_Fields {

    public function __construct( $field, $value = '', $unique = '', $where = '', $parent = '' ) {
      parent::__construct( $field, $value, $unique, $where, $parent );
    }

    public function render() {

		?>
		<div class="importer_confirmation importer_loader hidden">
			<div class="loader"></div>
		</div>
		<div class="importer_confirmation confirm hidden">
			<div class="importer_confirmation-msg">
				<p class="big"><?php esc_attr_e('Are you sure you want to import this demo?','mixano'); ?></p>
				<p class="small"><?php esc_attr_e('This will import the content, menu and widgets.','mixano'); ?></p>
				<div class="buttons">
					<a class="button button-primary confirm confirm-yes"><?php esc_attr_e('Yes','mixano') ?></a>
					<a class="button button-primary confirm confirm-no"><?php esc_attr_e('No','mixano') ?></a>
				</div>
				<?php mixano_delete_import_content(); ?>
			</div>
		</div>				
		<div class="importer_confirmation theme-not-active hidden">
			<div class="importer_confirmation-msg">
				<p>
				<?php echo sprintf( '%s <a href="%s" class="activate-theme">%s</a>%s <br><br>', 
					  esc_html__( 'Theme is not activated. Please ', 'mixano' ), 
					  esc_url( get_admin_url().'admin.php?page=mixano-options#tab=activate-theme' ),
					  esc_html__( 'activate it', 'mixano' ), 
					  esc_html__( ' using Envato purchase code.', 'mixano' ));
				?>				
				<?php echo sprintf( '%s <a href="%s" target="_blank">%s</a>', 
					  esc_html__( 'You can find your purchase code in your Envato account.', 'mixano' ),
					  esc_url( 'https://help.market.envato.com/hc/en-us/articles/202822600-Where-Is-My-Purchase-Code' ),	
					  esc_html__( 'Find out more', 'mixano' ));
				?>
				</p>
			</div>
		</div>		
		<div class="importer_confirmation success hidden">
			<div class="importer_confirmation-msg">
				<p class="big"><?php esc_attr_e('Import complete.','mixano'); ?></p>
				<p class="small"><?php esc_attr_e(' You can close this box by clicking outside it.','mixano'); ?>
			</div>
		</div>		
		<div class="importer_confirmation fail hidden">
			<div class="importer_confirmation-msg">
				<p><?php esc_attr_e('Sorry, demo was not imported successfully.','mixano'); ?></p>
			</div>
		</div>		
		<div class="importer_confirmation in-progress hidden">
			<div class="importer_confirmation-msg">
				<p class="big"><?php esc_attr_e('Importing...Please do not refresh this page!','mixano'); ?></p>
				<p class="small"><?php esc_attr_e('You will be informed once the importer is complete.','mixano'); ?></p>		
				<p class="small"><?php esc_attr_e('This process may take a few minutes.','mixano'); ?></p>			
				  <div class="importer_loader sk-bounce">
					<div class="sk-bounce-dot"></div>
					<div class="sk-bounce-dot"></div>
				  </div>	
				  
			</div>
		</div>
		
		<!--
		<div class="importer_confirmation delete-action">
			<div class="importer_confirmation-msg">
				<?php mixano_delete_import_content(); ?>
			</div>
		</div>		
		-->
		
		<?php
		echo $this->field_before();
		
		if( isset($this->field['options']) && !empty($this->field['options']) ){ ?>
			<div class="import-fields">
				<?php
					foreach($this->field['options'] as $val => $option){
						$url = isset($option['url']) ? $option['url'] : '';
						$desc = isset($option['desc']) ? $option['desc'] : '';
						?>
						<div class="import-field">
							<a href="#" data-val="<?php echo esc_attr($val); ?>">
								<img src="<?php echo esc_url($url); ?>">
								<p><?php echo esc_html($desc); ?></p>							
							</a>						
						</div>
					<?php
					}
				?>
				
				<div class="import-btn">
					<a class="button button-primary csf-import disabled"><?php esc_attr_e('Import','mixano'); ?></a>
				</div>
			</div>
			<?php
		} 
		
		echo $this->field_after();
		
		echo mixano_server_minimum_req();

    }

  }
}

/*
=================================================================================================================
mixano_delete_import_content() - Delete import content
=================================================================================================================
*/
function mixano_delete_import_content(){
?>
	<div class="delete_import_content">
		<div class="warning">
			<h2><?php esc_html_e('Not your first demo install?','mixano'); ?></h2>
			<p class="small">
				<?php esc_html_e('Use the bellow tool to remove data from previous imports. This will ensure the importer runs smoothly, and no duplicate content will be added such as menus, posts etc.','mixano'); ?><br>
				<?php esc_html_e('Once you have selected your action, click Yes to import the demo.','mixano'); ?>
			</p>			
		</div>
		<div class="options">
			<ul>
				<li>
					<div class="importer_delete_item">
						<h3><?php esc_html_e('Posts','mixano'); ?></h3>
						<select name="import_delete_posts">
							<option value=""><?php esc_html_e('Keep','mixano'); ?></option>
							<option value="trash"><?php esc_html_e('Trash','mixano'); ?></option>
							<option value="delete"><?php esc_html_e('Delete permanently','mixano'); ?></option>
						</select>
						<small><?php esc_html_e('Applies to all posts','mixano'); ?></small>	
					</div>
				</li>
				
				<li>
					<div class="importer_delete_item">
						<h3><?php esc_html_e('Pages','mixano'); ?></h3>
						<select name="import_delete_pages">
							<option value=""><?php esc_html_e('Keep','mixano'); ?></option>
							<option value="trash"><?php esc_html_e('Trash','mixano'); ?></option>
							<option value="delete"><?php esc_html_e('Delete permanently','mixano'); ?></option>
						</select>
						<small><?php esc_html_e('Applies to all pages','mixano'); ?></small>
					</div>
				</li>
				
				<li>
					<div class="importer_delete_item">
						<h3><?php esc_html_e('Widgets','mixano'); ?></h3>
						<select name="import_delete_widgets">
							<option value=""><?php esc_html_e('Keep','mixano'); ?></option>
							<option value="inactive"><?php esc_html_e('Set to inactive','mixano'); ?></option>
							<option value="delete"><?php esc_html_e('Delete permanently','mixano'); ?></option>
						</select>
						<small><?php esc_html_e('Applies to all widgets','mixano'); ?></small>
					</div>
				</li>
				
				<li>
					<div class="importer_delete_item">
						<h3><?php esc_html_e('Menu','mixano'); ?></h3>
						<select name="import_delete_menus">
							<option value=""><?php esc_html_e('Keep','mixano'); ?></option>
							<option value="delete"><?php esc_html_e('Delete permanently','mixano'); ?></option>
						</select>
						<small><?php esc_html_e('Applies to all menus','mixano'); ?></small>
					</div>
				</li>				
				
				<li>
					<div class="importer_delete_item">
						<h3><?php esc_html_e('Media','mixano'); ?></h3>
						<select name="import_delete_media">
							<option value=""><?php esc_html_e('Keep','mixano'); ?></option>
							<option value="delete"><?php esc_html_e('Delete permanently','mixano'); ?></option>
						</select>
						<small><?php esc_html_e('Applies to all media','mixano'); ?></small>
					</div>
				</li>
			</ul>
	
		</div>	
		<p class="warning small">
			<?php esc_html_e('Proceed with caution or create a backup first, if unsure!','mixano'); ?>
		</p>		

	</div>
<?php
}

/*
=================================================================================================================
mixano_server_minimum_req() - Check if server minimum requirements are met
=================================================================================================================
*/
function mixano_server_minimum_req(){

	$return='';
	$warning = array();
	$allowed_html_tags = array( 'div' => array ( 'id' => array() , 'class' => array() ),'ul' => array ( 'class' => array() ), 'i' => array ( 'class' => array() ),'span' => array ( 'class' => array() ), 'li' => array() , 'br' => array(), 'p' => array(), 'h3' => array( 'class' => array() ), 'b' => array(),     
		'a' => array(
			'href' => array(),
			'class' => array(),
			'rel' => array(),
		),	
		'svg' => array(
			'xmlns' => array(),
			'class' => array(),
			'viewBox' => array(),
		),		
		'path' => array(
			'd' => array(),
			'class' => array(),
			'viewBox' => array(),
		),
		'strong' => array()
	);
	
	$titles = array(
				'memory_limit'=> esc_html__('PHP memory limit','mixano'),						
				'max_execution_time'=> esc_html__('PHP time limit','mixano'),						
				'max_input_vars'=> esc_html__('PHP max input vars','mixano'),						
				'upload_size'=> esc_html__('Max upload size','mixano'),						
			);
	
	$msg = array(
		'memory_limit'=> mixano_svg( 'error-warning-line', false ).ini_get( 'memory_limit' ).'<br><span class="alert">' . esc_html__('Memory limit is good, however 256M is recommended.','mixano') . '</span>',
		'max_execution_time'=> mixano_svg( 'close-circle-line', false ).ini_get( 'max_execution_time' ).'<br><span class="alert">' . esc_html__('Mimimum is 60, recommended is 120.','mixano') . '</span>',
		'max_input_vars'=> mixano_svg( 'close-circle-line', false ).ini_get( 'max_input_vars' ).'<br><span class="alert">' . esc_html__('Mimimum of 3000 is recommended.','mixano') . '</span>',
		'upload_size'=> mixano_svg( 'close-circle-line', false ).size_format( wp_max_upload_size() ).'<br><span class="alert">' . esc_html__('Minimum of 8 MB is required.','mixano') . '</span>',
	);
	
	
	$warning []= ini_get( 'memory_limit' ) < 256 ? 'memory_limit' : '';
	$warning []= ini_get( 'max_execution_time' ) < 60 ? 'max_execution_time' : '';
	$warning []= ini_get( 'max_input_vars' ) < 3000 ? 'max_input_vars' : '';
	$warning []= size_format( wp_max_upload_size() ) < 8 ? 'upload_size' : '';
	
	
	$warnings = array_filter( $warning ); //delete empty values from array
	
	if( !empty( $warnings ) ){
		$return .= '<div id="server_req_error" class="modal">';

			$return .=  '<h3>' . esc_html__('Server minimum requirements not met','mixano') . '</h3>';
			$return .=  '<h3 class="explanation">' . esc_html__('What does this mean?','mixano') . '</h3>';
			$return .=  '<p>' . __('This will lead to bad / incomplete imports and  <strong>we really don\'t recomment it</strong>. <br> You can still use the importer, however consider resolving the issues bellow for optimal results. <br/> If you are unsure on how to do this, please contact your hosting provider.','mixano') . '</p>';

			$return .= '<ul class="system_status">';		
				foreach( $warnings as $val ){
					$return .= '<li><span class="detail">'.$titles[$val].'</span><span class="info">'.$msg[$val].'</span></li>';
				}
			$return .= '</ul>';
			$return .= '<a href="#close-modal" rel="modal:close" class="close-modal ">' . esc_html__('Close','mixano') . '</a>';
		$return .= '</div>';
		
		return wp_kses( $return, $allowed_html_tags );
	}
	
	return false;

}