<?php


/*
=================================================================================================================
mixano_get_all_posts_for_deletion() - get all posts by $post_type and delete / trash them
=================================================================================================================
*/
function mixano_get_all_posts_for_deletion( $post_type , $permanently = false ){
	
	$query = new WP_Query( array(
		'post_type' => $post_type,
		'post_status' => 'publish',
		'posts_per_page' => -1
	));

	while ( $query->have_posts() ) {
		$query->the_post();
		if ( $post_type === 'post' or $post_type === 'page' ){
			wp_delete_post( get_the_ID(), $permanently );
		}
		else{
			if ( $permanently === true ){
				wp_delete_post( get_the_ID(), true );
			}
			else{
				wp_trash_post ( get_the_ID() );
			}
		}
	}

	wp_reset_query();
	
}

/*
=================================================================================================================
mixano_set_inactive_widgets() - set all widgets to inactive
=================================================================================================================
*/
function mixano_set_inactive_widgets(){
	$sidebars_array = array('sidebar','footer-widget-area-1','footer-widget-area-2','footer-widget-area-3','footer-widget-area-4');
	$temp = array();	
	$sidebars_widgets = get_option("sidebars_widgets");	

	foreach( $sidebars_widgets as $sidebars_widget_name => $sidebars_widget ){
		
		if( in_array( $sidebars_widget_name, $sidebars_array ) ){
			
			foreach( $sidebars_widget as $key => $val ){
				$temp[$val] = '1';				
			}
			
			unset( $sidebars_widgets[$sidebars_widget_name] );			
			$sidebars_widgets[$sidebars_widget_name] = array();
		}
	}
	
	foreach( $temp as $key => $val ){
		$sidebars_widgets["wp_inactive_widgets"][] = $key;
	}
	
	update_option( "sidebars_widgets" , $sidebars_widgets );
	
}

/*
=================================================================================================================
mixano_delete_widgets() - remove all widgets
=================================================================================================================
*/
function mixano_delete_widgets(){
	
	$sidebars_array = array('sidebar','footer-widget-area-1','footer-widget-area-2','footer-widget-area-3','footer-widget-area-4');
	$sidebars_widgets = get_option("sidebars_widgets");
	
	foreach( $sidebars_widgets as $sidebars_widget_name => $sidebars_widget ){
		
		if( in_array( $sidebars_widget_name, $sidebars_array ) ){		
			unset( $sidebars_widgets[$sidebars_widget_name] );			
			$sidebars_widgets[$sidebars_widget_name] = array();
		}
		
		if( $sidebars_widget_name ==  'wp_inactive_widgets' ){
			foreach ( $sidebars_widgets['wp_inactive_widgets'] as $key => $widget_id ) {
				$pieces       = explode( '-', $widget_id );
				$multi_number = array_pop( $pieces );
				$id_base      = implode( '-', $pieces );
				$widget       = get_option( 'widget_' . $id_base );
				unset( $widget[ $multi_number ] );
				update_option( 'widget_' . $id_base, $widget );
				unset( $sidebars_widgets['wp_inactive_widgets'][ $key ] );
			}			
		}
	}
	update_option( "sidebars_widgets" , $sidebars_widgets );


}

/*
=================================================================================================================
mixano_delete_media() - remove all media attachments
=================================================================================================================
*/
function mixano_delete_media(){
$attachments = get_posts(
	array(
		'post_type'      => 'attachment',
		'posts_per_page' => -1,
		'post_status'    => 'any',
	)
	);
	foreach ( $attachments as $attachment ) {
		wp_delete_attachment( $attachment->ID );
	}
}