<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/*
=================================================================================================================
Recent Posts Widget
=================================================================================================================
*/
add_action( 'widgets_init', 'mixano_recent_posts_widget' );
function mixano_recent_posts_widget() {
	register_widget( 'mixano_recent_posts_widget' );
}

class Mixano_Recent_Posts_Widget extends WP_Widget {
	function __construct() {
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'mixano_recent_posts_widget', 'description' => esc_attr__('Display Recent Posts in a nice style','mixano') );
		 
		/* Widget control settings. */
		$control_ops = array( 'id_base' => 'mixano_recent_posts_widget' );
		 
		/* Create the widget. */
		parent::__construct( 'mixano_recent_posts_widget', esc_attr__('Mixano Recent Posts','mixano'), $widget_ops, $control_ops );
	}
	 
	function widget( $args, $instance ) {
		
		$post_no 	=  !empty( $instance['post_no'] ) ?  strip_tags( absint( $instance['post_no'] ) )  : 2 ;
		$title   	=  !empty( $instance['title'] )   ?  strip_tags( $instance['title'] )  : '' ;
		
		$query_args = array( 'posts_per_page' => $post_no ); 
		$query = new WP_Query( $query_args );
		
		extract( $args );

	?>
	<div class="widget"><!-- widget -->
		<h2><?php echo esc_html( $title ); ?></h2><span class="line"></span>
			<div class="sidebar-posts">
				
				<?php while ( $query->have_posts() ) { $query->the_post(); ?>			
				
					<article <?php post_class(); ?>>
						<div class="post-widget">
							<div class="mixano-row">
							<?php if ( has_post_thumbnail() ) { ?>
								<div class="col-desktop-4 col-tablet-4 col-small-tablet-12 col-mobile-12 thumb">
									<?php mixano_post_thumb( false,  false , true , false , true ); ?>
								</div>
								<div class="col-desktop-8 col-tablet-8 col-small-tablet-12 col-mobile-12">
									<?php mixano_first_cat_link(); ?>
									<h3 class="post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
								</div>
							<?php } else { ?>
								<div class="col-desktop-8 no-thumb-widget col-tablet-8 col-small-tablet-12 col-mobile-12">
									<?php mixano_first_cat_link(); ?>
									<h3 class="post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
								</div>
							<?php } ?>
							</div>
						</div>
					</article>				
				
				<?php } wp_reset_postdata(); ?>
			</div>
	</div><!--/ widget -->
<?php	
}
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		 
		$instance['title']   	=   sanitize_text_field( $new_instance['title'] );
		$instance['post_no'] 	=   is_integer( intval( $new_instance['post_no'] ) ) ? intval( $new_instance['post_no'] ) : 2;
		
		return $instance;
	}

	function form( $instance ) {
		
		$title	  			= isset( $instance['title'] )   ? strip_tags( esc_attr( $instance['title'] ) ) : esc_attr__( 'Latest news','mixano' );
		$post_no  			= isset( $instance['post_no'] ) ? strip_tags( absint( $instance['post_no'] ) ) : 2;
	
		?>
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title','mixano' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $title ); ?>">
		</p>
		
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'post_no' ) ); ?>"><?php esc_html_e( 'Number of posts','mixano' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'post_no' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'post_no' ) ); ?>" value="<?php echo esc_attr( $post_no ); ?>">
		</p>
		
	<?php
	}
}