<?php
/**
* Plugin Name: Mixano Core
* Plugin URI: https://wowlayers.com
* Description: Register widgets, options and core elements for Mixano theme
* Version: 1.1.4
* Author: WOW Layers
* Author URI: https://wowlayers.com
* Text Domain: mixano
**/

//exit if accessed directly
defined( 'ABSPATH' ) or exit;

//defines
define( 'MIXANO_PLUGIN_DIR', plugin_dir_path(__FILE__) );
define( 'MIXANO_PLUGIN_URI', plugin_dir_url( __FILE__ ) );

/*
=================================================================================================================
mixano_plugins_core() - add required > hooked @ plugins_loaded
=================================================================================================================
*/
function mixano_plugins_core() {
	require_once( MIXANO_PLUGIN_DIR .'/inc/functions.php' );
	require_once( MIXANO_PLUGIN_DIR .'/inc/downloads-views.php' );
	require_once( MIXANO_PLUGIN_DIR .'/inc/widgets/posts.php' );
	require_once( MIXANO_PLUGIN_DIR .'/inc/widgets/popular-downloads.php' );
	require_once( MIXANO_PLUGIN_DIR .'/inc/widgets/popular-posts.php' );
	require_once( MIXANO_PLUGIN_DIR .'/inc/widgets/categories.php' );
	if ( class_exists( 'WPCF7' ) ){
		require_once( MIXANO_PLUGIN_DIR .'/inc/wpcf7.php' );
	}
	require_once( MIXANO_PLUGIN_DIR .'/inc/syntax_highlight.php' );
	require_once( MIXANO_PLUGIN_DIR .'/inc/activation.php' );
}
add_action( 'plugins_loaded', 'mixano_plugins_core' );

/*
=================================================================================================================
mixano_plugin_styles() - load the plugin frontend styles
=================================================================================================================
*/
function mixano_plugin_styles(){

}
add_action('wp_enqueue_scripts', 'mixano_plugin_styles');

/*
=================================================================================================================
mixano_plugin_scripts() - load the plugin frontend scripts
=================================================================================================================
*/
function mixano_plugin_scripts(){
	
}
//add_action('wp_enqueue_scripts', 'mixano_plugin_scripts');


/*
=================================================================================================================
mixano_plugin_admin_styles() - load the plugin admin styles
=================================================================================================================
*/
function mixano_plugin_admin_styles(){
	wp_enqueue_style( 'mixano-admin-options' , MIXANO_PLUGIN_URI.'/css/admin-options.css', array(), '1.0', 'all' );
	wp_enqueue_style( 'modal' , MIXANO_PLUGIN_URI.'/css/jquery.modal.css', array(), '1.0', 'all' );
}
add_action( 'admin_enqueue_scripts', 'mixano_plugin_admin_styles' );

/*
=================================================================================================================
mixano_plugin_admin_scripts() - load the plugin admin scripts
=================================================================================================================
*/
function mixano_plugin_admin_scripts() {
	wp_enqueue_script( 'modal', MIXANO_PLUGIN_URI."/js/jquery.modal.min.js", array( 'jquery' ), '', true );
	wp_register_script( 'mixano-admin-options', MIXANO_PLUGIN_URI."/js/admin-options.js", array( 'jquery' ), '', true );
	
	$data = array( 
		'nonce' => wp_create_nonce( 'mixano_plugin_data' ), 
		'ajax_url' => admin_url( 'admin-ajax.php' ),
		'server_requirements' => esc_html__('Server minimum requirements not met. Click for info!','mixano')
	);	
	wp_localize_script( 'mixano-admin-options', 'mixano_plugin_data', $data );
	wp_enqueue_script('mixano-admin-options');
}
add_action('admin_enqueue_scripts', 'mixano_plugin_admin_scripts');


/* If Mixano theme is not active - deactivate plugin - this is a theme specific plugin  */
$theme = wp_get_theme();
$theme_name =  $theme->get( 'Name' );
if ( $theme_name !== 'Mixano' ) {
	if ( !function_exists( 'deactivate_plugins' ) ){
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	}
    deactivate_plugins( plugin_basename( __FILE__ ) );
	/* wp_die( __( 'Mixano Core plugin requires Mixano theme in order to be activated','mixano' ) ); */
}




/*
=================================================================================================================
mixano_dequeue_edd_styles() - dequeue the CSS files for edd
=================================================================================================================
*/
function mixano_dequeue_edd_styles() {
	
	if ( class_exists( 'Easy_Digital_Downloads' ) ){
		wp_dequeue_style( 'edd-styles' );
	}	
}
add_action( 'wp_print_styles', 'mixano_dequeue_edd_styles' );

/*
=================================================================================================================
mixano_dequeue_edd_scripts() - dequeue the js files for edd
=================================================================================================================
*/
function mixano_dequeue_edd_scripts() {
	
	if ( class_exists( 'Easy_Digital_Downloads' ) ){
		wp_deregister_script( 'edd-ajax' );
	}
}
add_action( 'wp_print_scripts', 'mixano_dequeue_edd_scripts' );


/*
=================================================================================================================
mixano_core_load_textdomain() - Load plugin text domain
=================================================================================================================
*/
function mixano_core_load_textdomain() {
  load_plugin_textdomain( 'mixano', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' ); 
}
add_action( 'init', 'mixano_core_load_textdomain' );