<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/*
=================================================================================================================
mixano_widgets_init() - add widget areas
=================================================================================================================
*/
function mixano_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'mixano' ),
		'id'            => 'sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2>',
		'after_title'   => '</h2><span class="line"></span>',
	) );	
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area 1', 'mixano' ),
		'id'            => 'footer-widget-area-1',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2>',
		'after_title'   => '</h2><span class="line"></span>',
	) );	
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area 2', 'mixano' ),
		'id'            => 'footer-widget-area-2',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2>',
		'after_title'   => '</h2><span class="line"></span>',
	) );	
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area 3', 'mixano' ),
		'id'            => 'footer-widget-area-3',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2>',
		'after_title'   => '</h2><span class="line"></span>',
	) );	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area 4', 'mixano' ),
		'id'            => 'footer-widget-area-4',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2>',
		'after_title'   => '</h2><span class="line"></span>',
	) );

}
add_action( 'widgets_init', 'mixano_widgets_init' );


/**
 * Custom walker class for widget nav
 */
class Mixano_Widget_Custom_Walker extends Walker_Nav_Menu {
 
    function start_lvl( &$output, $depth = 0, $args = array() ) {
        // Depth-dependent classes.
        $indent = ( $depth > 0  ? str_repeat( "\t", $depth ) : '' ); // code indent
        $display_depth = ( $depth + 1); // because it counts the first submenu as 0
        $classes = array(
            'sub-menu-widget'
        );
        $class_names = implode( ' ', $classes );
 
        // Build HTML for output.
        $output .= "\n" . $indent . '<ul class="' . $class_names . '">' . "\n";
    }
    function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
        global $wp_query;
        $indent = ( $depth > 0 ? str_repeat( "\t", $depth ) : '' ); // code indent
 
        // Depth-dependent classes.
        $depth_classes = array( );
        $depth_class_names = esc_attr( implode( ' ', $depth_classes ) );
 
        // Passed classes.
        $classes = empty( $item->classes ) ? array() : (array) $item->classes;
        $class_names = esc_attr( implode( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) ) ); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
 
		if ( is_object( $args ) ){

			// Build HTML.
			$output .= $indent . '<li id="nav-menu-item-'. $item->ID . '" class="' . $depth_class_names . ' ' . $class_names . '">';
	 
			// Link attributes.
			$attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
			$attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
			$attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
			$attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';
			$attributes .= ' class="menu-link ' . ( $depth > 0 ? 'sub-menu-link' : 'main-menu-link' ) . '"';
	 
			// Build HTML output and pass through the proper filter.
			$item_output = sprintf( '%1$s<a%2$s>%3$s%4$s</a>%5$s',
				$args->before,
				$attributes,
				$args->link_before,
				apply_filters( 'the_title', $item->title, $item->ID ), // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
				$args->after
			);
			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args ); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
			
		}
    }
}

function mixano_custom_walker_widget( $args ) {
	$args['menu_class'] = 'widget-nav-menu';
    return array_merge( $args, array(
        'walker' => new Mixano_Widget_Custom_Walker(),
    ) );
}
add_filter( 'widget_nav_menu_args', 'mixano_custom_walker_widget' );


/*
=================================================================================================================
mixano_comment() - Template for comments and pingbacks.
=================================================================================================================
*/
function mixano_comment( $comment, $args, $depth ) {
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php comment_author_link(); ?><?php comment_text(); ?></p>
	<?php
			break;
		default :
	?>
	<!-- comment level 1 -->
	<div class="comment-container"><!-- comment-container -->
		<div class="comment-author-img"><!-- comment-author-img -->
			<?php echo get_avatar( $comment, 80 ); ?>
		</div><!--/ comment-author-img -->
		<div class="comment-holder"><!-- comment-holder -->
			<div class="comment-details-holder"><!-- comment-details-holder -->
				<div class="comment-author"><h3><?php comment_author_link(); ?></h3></div>
				<div class="comment-date upper-heading secondary-font"><?php comment_date( get_option( 'date_format' ) ); ?></div>
				<div class="the-comment"><?php comment_text(); ?></div>
				<div class="comment-reply secondary-font"><?php comment_reply_link( array( 'depth' => $depth, 'max_depth' => $args['max_depth'],'reply_text'=>esc_html__( 'Reply','mixano' ) ) ); ?></div>
			</div><!--/ comment-details-holder -->
		</div><!--/ comment-holder -->
		
	</div><!--/ comment-container -->
	<?php
			break;
	endswitch;
}

/*
=================================================================================================================
mixano_excerpt() - Get excerpt with custom length
=================================================================================================================
*/
function mixano_excerpt( $charlength ) {
	$excerpt = get_the_excerpt();
	$charlength++;

	if ( mb_strlen( $excerpt ) > $charlength ) {
		$subex = mb_substr( $excerpt, 0, $charlength - 5 );
		$exwords = explode( ' ', $subex );
		$excut = - ( mb_strlen( $exwords[ count( $exwords ) - 1 ] ) );
		if ( $excut < 0 ) {
			echo esc_attr( mb_substr( $subex, 0, $excut ) );
		} else {
			echo esc_attr( $subex );
		}
	} 
	else {
		echo esc_attr( $excerpt );
	}
}


/*
=================================================================================================================
mixano_the_loop() - Custom theme loop
=================================================================================================================
*/
function mixano_the_loop(){
	$counter = 0;
	if( have_posts() ) {
		while( have_posts() ) {
		the_post();
		
			if ( mixano_option( 'ads','post-ad-position' ) == $counter+1 && mixano_option( 'ads','enable-post-ad' ) == 1 && function_exists ( 'mixano_plugins_core' ) ) {
				$counter++;
				get_template_part( 'templates/ad-post' );
			}	
			get_template_part( 'templates/article' ); 		
		
			$counter++;
		}
		$args = array( 'prev_text' => esc_html__( '&laquo;','mixano' ), 'next_text' => esc_html__( '&raquo;','mixano' ) );
		the_posts_pagination( $args );
	}//end if have_posts
}


/*
=================================================================================================================
mixano_the_loop_carousel() - Custom theme carousel loop
=================================================================================================================
*/
function mixano_the_loop_carousel(){

	$post_no = mixano_option('carousel-nr-posts');
	
	$args = array( 'posts_per_page' => $post_no, 'meta_key' => 'post-views-count' , 'orderby' => 'meta_value_num' ); 
	$query = new WP_Query( $args );	

	while ( $query->have_posts() ){
		$query->the_post(); ?>
		<div class="slick-slide">
			<?php get_template_part( 'templates/carousel-post' ); ?>
		</div>
	<?php	
	}//end if have_posts
	wp_reset_postdata();
}

/*
=================================================================================================================
mixano_carousel_has_posts() - Check if there are any posts to be displayed in the carousel
=================================================================================================================
*/
function mixano_carousel_has_posts(){
	$post_no = mixano_option('carousel-nr-posts');
	$args = array( 'posts_per_page' => $post_no, 'meta_key' => 'post-views-count' , 'orderby' => 'meta_value_num' ); 
	$query = new WP_Query( $args );
	if ( $query->found_posts > 0 ){
		return true;
	}
	return false;
}

/*
=================================================================================================================
mixano_comment_form() - Custom comment form
=================================================================================================================
*/
function mixano_comment_form(){
	
	if ( !isset( $aria_req ) )  $aria_req = '';
	if ( !isset( $commenter['comment_author'] ) )  $commenter['comment_author'] = '';
	if ( !isset( $commenter['comment_author_email'] ) )  $commenter['comment_author_email'] = '';
	if ( !isset( $commenter['comment_author_url'] ) )  $commenter['comment_author_url'] = '';
	
	if ( !is_user_logged_in() ){ 	

	$args = array(
	
		'title_reply'       => '',
		'title_reply_before'       => '<h3 class="upper-heading dark">'.esc_html__( 'Have somehting to say?','mixano' ).'<span class="dark-line"></span></h3><h2>'.esc_html__( 'Leave a comment','mixano' ).'<span class="main-color-1">.</span></h2>',
		'title_reply_after'       => '',
		'comment_field' =>'<div class="mixano-row comment"><div class="col-desktop-6 comment"><label>'.esc_attr__( 'Comment','mixano' ).'</label><textarea id="comment" name="comment"></textarea></div>',
		'fields' =>  array(
			 'author' =>
				'<div class="col-desktop-6 comment-details"><label>'.esc_html__( 'Name','mixano' ).'</label><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .'"' . $aria_req . ' />',

			  'email' =>
				'<label>'.esc_html__( 'Email','mixano' ).'</label><input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) .'"' . $aria_req . ' />',

			  'url' =>
				'<label>'.esc_html__( 'Website','mixano' ).'</label><input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) .'" /></div></div>',
			  
			  'cookies' => '',			
			),
		'comment_notes_before' => '',
		
		);
	
	}
	
	else{
		$args = array(

		'title_reply'       => '',
		'title_reply_before'       => '<h3 class="upper-heading dark">'.esc_html__( 'Have somehting to say?','mixano' ).'<span class="dark-line"></span></h3><h2>'.esc_html__( 'Leave a comment','mixano' ).'<span class="main-color-1">.</span></h2>',
		'title_reply_after'       => '',
		'comment_field' =>'<textarea id="comment"  name="comment"></textarea>',
		'fields' =>  array(
			 'author' =>
				'<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .'"' . $aria_req . ' />',

			  'email' =>
				'<input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) .'"' . $aria_req . ' />',

			  'url' =>
				'<input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) .'" />',
			  
			  'cookies' => '',			
			),
		'comment_notes_before' => '',
		
		);		
	}
	
	return $args;
}